==============
geoglows.plots
==============

Plots for Streamflow Data
~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: geoglows.plots
    :members:
        hydroviewer, forecast_stats, forecast_records, forecast_ensembles, historic_simulation, flow_duration_curve
    :noindex:

Tables for Streamflow Data
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: geoglows.plots
    :members:
        probabilities_table, return_periods_table
    :noindex:

Plots for Bias Corrected Data
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: geoglows.plots
    :members:
        corrected_historical, corrected_scatterplots, corrected_day_average, corrected_month_average, corrected_volume_compare
    :noindex:
